@@ -8,7 +8,7 @@ pub type ExchangeRates = HashMap<String, f64>;
 pub fn parse_exchange_rates(xml_content: &str) -> Option<ExchangeRates> {
     let mut rates = ExchangeRates::default();
 
-    let mut reader = Reader::from_str(&xml_content);
+    let mut reader = Reader::from_str(xml_content);
     loop {
         match reader.read_event().ok()? {
             Event::Eof => break,
@@ -33,18 +33,22 @@ pub fn parse_exchange_rates(xml_content: &str) -> Option<ExchangeRates> {
     Some(rates)
 }
 
+#[cfg(feature = "fetch-exchangerates")]
 const ECB_XML_URL: &str = "https://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml";
 
+#[cfg(feature = "fetch-exchangerates")]
 fn fetch_ecb_xml() -> Option<String> {
     attohttpc::get(ECB_XML_URL).send().ok()?.text().ok()
 }
 
+#[cfg(feature = "fetch-exchangerates")]
 pub fn fetch_exchange_rates() -> Option<ExchangeRates> {
     let xml_content = fetch_ecb_xml()?;
     parse_exchange_rates(&xml_content)
 }
 
 #[cfg(test)]
+#[cfg(feature = "fetch-exchangerates")]
 mod tests {
     use super::*;
 
